/**
 * intervalometer
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Open Software License (OSL 3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://opensource.org/licenses/osl-3.0.php
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to tomi.suviola@gmail.com so I can send you a copy immediately.
 *
 * @copyright  Copyright (c) 2010 Tomi Suviola
 * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
 */

#include <QtGui>
#include "interval.h"
#include "intervalwindow.h"
#include "camerainterface.h"

Q_IMPORT_PLUGIN(exampleplugin)
Q_IMPORT_PLUGIN(n900plugin)
Q_IMPORT_PLUGIN(irplugin)

int main(int argv, char *args[])
{
    QApplication app(argv, args);

    QCoreApplication::setOrganizationName("Tx");
    QCoreApplication::setOrganizationDomain("tonet.org");
    QCoreApplication::setApplicationName(APPNAME);

    Interval *model = new Interval();
    IntervalWindow window(model);
    window.show();

    return app.exec();
}
